<?php

namespace Drupal\xray_audit_insight\Plugin\insights;

use Drupal\Core\Render\Markup;
use Drupal\xray_audit\Plugin\XrayAuditTaskPluginInterface;
use Drupal\xray_audit_insight\Plugin\XrayAuditInsightPluginBase;

/**
 * Plugin implementation of queries_data_node.
 *
 * @XrayAuditInsightPlugin (
 *   id = "modules_not_enabled",
 *   label = @Translation("Modules Not enabled"),
 *   description = @Translation("Modules not enabled"),
 *   sort = 1
 * )
 */
class XrayAuditEntityModulesNotEnabledPlugin extends XrayAuditInsightPluginBase {

  /**
   * {@inheritdoc}
   */
  public function getInsights(): array {
    $values = ['custom_modules_not_enabled' => FALSE];

    if ($this->isCustomModulesNotEnabled()) {
      $values['custom_modules_not_enabled'] = TRUE;
    }

    return $values;
  }

  /**
   * {@inheritdoc}
   */
  public function getInsightsForDrupalReport(): array {
    $build = [];
    $insights = $this->getInsights();

    $title = $this->t('Custom modules');
    $path_report = $this->getPathReport('modules', 'modules');

    if ($insights['custom_modules_not_enabled'] === FALSE) {
      $description = $this->t('All custom modules are enabled on some split.');
      $severity = NULL;
    }
    else {
      $description = $this->t('Custom modules have been detected that are not enabled on any split and may be candidates for removal. Check module report: %report', [
        '%report' => Markup::create("<a href=\"{$path_report}\">Modules report</a>"),
      ]);
      $severity = REQUIREMENT_WARNING;
    }

    $build['custom_modules_not_enabled'] = $this->buildInsightForDrupalReport($title, NULL, $description, $severity);

    return $build;
  }

  /**
   * Modules is not enabled.
   *
   * @return bool
   *   Modules enables.
   */
  protected function isCustomModulesNotEnabled(): bool {
    $result = FALSE;

    $task_plugin = $this->getInstancedPlugin('modules', 'modules');
    if (!$task_plugin instanceof XrayAuditTaskPluginInterface) {
      return FALSE;
    }

    $data = $task_plugin->getDataOperationResult('modules');

    foreach ($data['custom'] as $module) {
      if ($module['enabled_by'] === '') {
        $result = TRUE;
        break;
      }
    }
    return $result;
  }

}
